@@ -5,7 +5,8 @@ import logging
 import json
 import ssl
 import uuid
-from terncy import version
+from terncy.version import __version__
+import terncy.event as event
 import ipaddress
 from datetime import datetime
 from enum import Enum
@@ -157,9 +158,9 @@ class Terncy:
 
     async def start(self):
         """Connect to Terncy system and start event monitor."""
-        logger.info(
+        print(
             "Terncy v%s starting connection to %s:%d.",
-            version.__version__,
+            __version__,
             self.ip,
             self.port,
         )
@@ -179,25 +180,39 @@ class Terncy:
             self.username,
             self.token,
         )
-        async with aiohttp.ClientSession() as session:
-            async with session.ws_connect(
-                url, ssl=ssl._create_unverified_context()
-            ) as ws:
-                self._connection = ws
-                async for msg in ws:
-                    msgObj = msg.json()
-                    print("got message:", datetime.now())
-                    print(msgObj)
-                    if "rspId" in msgObj:
-                        rsp_id = msgObj["rspId"]
+        try:
+            async with aiohttp.ClientSession() as session:
+                async with session.ws_connect(
+                    url, ssl=ssl._create_unverified_context()
+                ) as ws:
+                    self._connection = ws
+                    if self._event_handler:
+                        self._event_handler(self, event.Connected())
+                    async for msg in ws:
+                        if msg.type == aiohttp.WSMsgType.CLOSE:
+                            print("got close message:", datetime.now())
+                            if self._event_handler:
+                                self._event_handler(self, event.Disconnected())
+                            return
+                        print("got message:", datetime.now())
+                        msgObj = msg.json()
+                        print(msgObj)
+                        if "rspId" in msgObj:
+                            rsp_id = msgObj["rspId"]
 
-                        if rsp_id in self._pending_requests:
-                            req = self._pending_requests[rsp_id]
-                            req["_response"] = msgObj
-                            req["event"].set()
-                    if "intent" in msgObj and msgObj["intent"] == "event":
-                        if self._event_handler:
-                            self._event_handler(self, msgObj)
+                            if rsp_id in self._pending_requests:
+                                req = self._pending_requests[rsp_id]
+                                req["_response"] = msgObj
+                                req["event"].set()
+                        if "intent" in msgObj and msgObj["intent"] == "event":
+                            if self._event_handler:
+                                self._event_handler(self, event.Message(msg))
+        except aiohttp.client_exceptions.ClientConnectionError as e:
+            print("failed to connect server:", datetime.now())
+            print(e)
+            if self._event_handler:
+                self._event_handler(self, event.Disconnected())
+            return
 
     async def _wait_for_response(self, req_id, req, timeout):
         evt = asyncio.Event()
